@@ -53,9 +53,9 @@ static void UIDisplayItem (const struct newsitem* current_item, const struct fee
 	erase();
 
 	const char* feed_title = current_feed->description;
-	if (!feed_title)
+	if (!feed_title || !feed_title[0])
 	    feed_title = current_feed->title;
-	if (!feed_title)
+	if (!feed_title || !feed_title[0])
 	    feed_title = "* " SNOWNEWS_NAME " " SNOWNEWS_VERSTRING;
 
 	// Print feed title
@@ -83,9 +83,9 @@ static void UIDisplayItem (const struct newsitem* current_item, const struct fee
 	    if (titlelen < COLS - xdesc*2)
 		xtitle = (COLS - titlelen) / 2u;
 	    move (ydesc, xtitle);
-	    attr_set (WA_BOLD, 2, NULL);
+	    attron (WA_BOLD);
 	    add_utf8 (current_item->data->title);
-	    attr_set (WA_NORMAL, 0, NULL);
+	    attroff (WA_BOLD);
 	    mvhline (++ydesc, 0, 0, COLS);
 	    ++ydesc;
 	}
@@ -155,6 +155,10 @@ static void UIDisplayItem (const struct newsitem* current_item, const struct fee
 	    --topline;
 	else if (uiinput == KEY_DOWN && topline + pagesz < desclines)
 	    ++topline;
+	else if (uiinput == KEY_HOME || uiinput == 'H')
+	    topline = 0;
+	else if (uiinput == KEY_END || uiinput == 'G')
+	    topline = (desclines > pagesz ? desclines - pagesz : 0);
 	else if (resize_dirty || uiinput == KEY_RESIZE) {
 	    clear();
 	    resize_dirty = false;
@@ -218,10 +222,10 @@ static int UIDisplayFeed (struct feed* current_feed)
 
 	// Print a title or something
 	const char* title = current_feed->description;
-	if (!title)
+	if (!title || !title[0])
 	    title = current_feed->title;
-	if (!title)
-	    title = "Untitled";
+	if (!title || !title[0])
+	    title = _("No title");
 	UISupportDrawHeader (title);
 
 	// We start the item list below the header
@@ -266,15 +270,8 @@ static int UIDisplayFeed (struct feed* current_feed)
 	    move (ypos, 0);
 	    clrtoeol();
 
-	    if (!item->data->readstatus) {
-		// Apply color style.
-		if (!_settings.monochrome) {
-		    attron (COLOR_PAIR (2));
-		    if (_settings.color.newitemsbold)
-			attron (WA_BOLD);
-		} else
-		    attron (WA_BOLD);
-	    }
+	    if (!item->data->readstatus)
+		attron (WA_BOLD);
 
 	    if (item == highlighted) {
 		current_item = item;
@@ -308,15 +305,8 @@ static int UIDisplayFeed (struct feed* current_feed)
 	    ++ypos;
 	    if (item == highlighted)
 		attroff (WA_REVERSE);
-	    if (!item->data->readstatus) {
-		// Disable color style.
-		if (!_settings.monochrome) {
-		    attroff (COLOR_PAIR (2));
-		    if (_settings.color.newitemsbold)
-			attroff (WA_BOLD);
-		} else
-		    attroff (WA_BOLD);
-	    }
+	    if (!item->data->readstatus)
+		attroff (WA_BOLD);
 
 	    if (itemnum >= ymax)
 		break;
@@ -438,7 +428,7 @@ static int UIDisplayFeed (struct feed* current_feed)
 		}
 	    } else if (uiinput == _settings.keybindings.markunread && highlighted) {
 		highlighted->data->readstatus = !highlighted->data->readstatus;
-		current_feed->mtime = curtime;
+		highlighted->data->parent->mtime = curtime;
 		reloaded = true;
 	    } else if (uiinput == _settings.keybindings.about)
 		UIAbout();
@@ -703,9 +693,9 @@ void UIMainInterface (void)
 
 	    int columns;
 	    if (cur_ptr->feedcategories != NULL)
-		columns = COLS - 26 - strlen (_("new"));
+		columns = COLS - 26 - strlen ("new");
 	    else
-		columns = COLS - 9 - strlen (_("new"));
+		columns = COLS - 9 - strlen ("new");
 
 	    mvaddn_utf8 (ypos, 1, cur_ptr->title, columns);
 	    if (xmlStrlen ((xmlChar*) cur_ptr->title) > columns)
@@ -719,11 +709,11 @@ void UIMainInterface (void)
 		const char* localized_msg = ngettext ("%3u new", "%3u new", newcount);
 		char msgbuf[16];
 		snprintf (msgbuf, sizeof (msgbuf), localized_msg, newcount);
-		mvadd_utf8 (ypos, COLS - 1 - strlen (localized_msg), msgbuf);
+		mvadd_utf8 (ypos, COLS - 1 - utf8_length (localized_msg), msgbuf);
 	    }
 
 	    if (cur_ptr->feedcategories != NULL)
-		mvaddn_utf8 (ypos, COLS - 21 - strlen (_("new")), cur_ptr->feedcategories->name, 15);
+		mvaddn_utf8 (ypos, COLS - 21 - strlen ("new"), cur_ptr->feedcategories->name, 15);
 
 	    ++ypos;
 
